@@ -97,9 +97,7 @@ void objectdefaults(objinstptr newinst, objectptr thisobj, int x, int y)
    newinst->bbox.width = thisobj->bbox.width;
    newinst->bbox.height = thisobj->bbox.height;
 
-#ifdef SCHEMA
    newinst->schembbox = NULL;
-#endif
 }
 
 /*--------------------------------------*/
@@ -175,14 +173,12 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    newlabel->string->data.font = areastruct.psfont;
    newlabel->string->nextpart = NULL;
 
-#ifdef SCHEMA
    newlabel->pin = False;
    if (areastruct.schemon) {
       newlabel->pin = dopin;
       if (dopin == LOCAL) newlabel->color = LOCALPINCOLOR;
       else if (dopin == INFO) newlabel->color = INFOLABELCOLOR;
    }
-#endif
 
    newlabel->justify = areastruct.justify;
    newlabel->position.x = x;
@@ -331,7 +327,6 @@ void labeltext(int keypressed, char *clientdata)
    }
    else if (isbound(keypressed, XCF_Text_Return)) {
       Boolean hasstuff = False;   /* Check for null string */
-      Boolean do_all = True;
       stringpart *tmppos;
 
       for (tmppos = curlabel->string; tmppos != NULL; tmppos = tmppos->nextpart) {
@@ -345,9 +340,7 @@ void labeltext(int keypressed, char *clientdata)
       if (hasstuff && (eventmode != TEXT3_MODE && eventmode != CATTEXT_MODE)) {
 	 topobject->parts++;
 	 incr_changes(topobject);
-#ifdef SCHEMA
 	 invalidate_netlist(topobject);
-#endif
 
       }
       else if (!hasstuff && (eventmode == TEXT3_MODE)) topobject->parts--;
@@ -399,16 +392,13 @@ void labeltext(int keypressed, char *clientdata)
       else {	/* (hasstuff && eventmode != CATTEXT_MODE) */
 	 eventmode = NORMAL_MODE;
 	 incr_changes(topobject);
-#ifdef SCHEMA
 	 if (curlabel->pin != False) invalidate_netlist(topobject);
-#endif
       }
 
       setdefaultfontmarks();
       setcolormark(areastruct.color);
       if (labelbuf != NULL) {
 
-#ifdef SCHEMA
 	 /* If the original label (before modification) is a pin in a	*/
 	 /* schematic/symbol with a matching symbol/schematic, and the	*/
 	 /* name is unique, change every pin in the matching symbol/	*/
@@ -427,18 +417,12 @@ void labeltext(int keypressed, char *clientdata)
 	       invalidate_netlist(topobject->symschem);
 	    }
 	 }
-#endif
 	
 	 freelabel(labelbuf);
 	 labelbuf = NULL;
 	 resolveparams(areastruct.topinstance);
-	 if (do_all >= 0)
-            updateinstparam(areastruct.topinstance, do_all);
-	 else /* do_all == -1 */
-	    calcbbox(areastruct.topinstance);
-#ifdef SCHEMA
+         updateinstparam(topobject);
 	 setobjecttype(topobject);
-#endif
       }
       else
          calcbbox(areastruct.topinstance);
@@ -623,11 +607,9 @@ void labeltext(int keypressed, char *clientdata)
       areastruct.origin.y = curlabel->position.y + (curlabel->justify &
 	  NOTBOTTOM ? (curlabel->justify & TOP ? -tmpheight : -tmpheight / 2)
 	  : 0);
-#ifdef SCHEMA
       if (curlabel->pin)
          pinadjust(curlabel->justify, &(areastruct.origin.x),
 		&(areastruct.origin.y), 1);
-#endif
       XcSetFunction(GXcopy);
       redrawtext(curlabel);
    }
@@ -1665,6 +1647,21 @@ void join()
    free(direc);
 }
 
+/*----------------------------------------------*/
+/* Add a new point to a polygon			*/
+/*----------------------------------------------*/
+
+void poly_add_point(polyptr thispoly, XPoint *newpoint) {
+   XPoint *tpoint;
+
+   thispoly->number++;
+   thispoly->points = (XPoint *)realloc(thispoly->points,
+			thispoly->number * sizeof(XPoint));
+   tpoint = thispoly->points + thispoly->number - 1;
+   tpoint->x = newpoint->x;
+   tpoint->y = newpoint->y;
+}
+
 /*-------------------------------------------------*/
 /* ButtonPress handler while a wire is being drawn */
 /*-------------------------------------------------*/
@@ -1703,12 +1700,9 @@ void wirebutton(XButtonEvent *event)
    }
 
    if (newwire && event->button == Button1) {
-      if (++newwire->number == 3) newwire->style = areastruct.style;
-      newwire->points = (XPoint *)realloc(newwire->points, newwire->number
-		* sizeof(XPoint));
-      tpoint = newwire->points + newwire->number - 1;
-      tpoint->x = userpt.x;
-      tpoint->y = userpt.y;
+      if (newwire->number == 2)
+	 newwire->style = areastruct.style;
+      poly_add_point(newwire, &userpt);
    }
    else if (newwire == NULL || event->button != Button3)
       xcRemoveEventHandler(areastruct.area, PointerMotionMask, False,
@@ -1720,9 +1714,7 @@ void wirebutton(XButtonEvent *event)
          XcSetForeground(newwire->color);
 	 topobject->parts++;
 	 incr_changes(topobject);
-#ifdef SCHEMA
 	 if (!nonnetwork(newwire)) invalidate_netlist(topobject);
-#endif
       }
       UDrawPolygon(newwire);
       if (event->button == Button3)
