@@ -67,11 +67,11 @@ extern short help_up;
 static char *function_names[NUM_FUNCTIONS + 1] = {
    "Page", "Justify", "Superscript", "Subscript", "Normalscript",
    "Nextfont", "Boldfont", "Italicfont", "Normalfont", "Underline",
-   "Overline", "ISO Encoding", "Return", "Halfspace", "Quarterspace",
+   "Overline", "ISO Encoding", "Halfspace", "Quarterspace",
    "Special", "Tab Stop", "Tab Forward", "Tab Backward",
    "Text Return", "Text Delete", "Text Right", "Text Left",
    "Text Up", "Text Down", "Text Split", 
-   "Text Home", "Text End", "Return Char", "Parameter",
+   "Text Home", "Text End", "Linebreak", "Parameter",
    "Parameterize Point", "Break at Point", "Delete Point", "Insert Point",
    "Append Point", "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
@@ -85,12 +85,8 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Undelete", "Select Save", "Unselect", "Dashed", "Dotted",
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
    "Nothing", "Exit",
-
-#ifdef SCHEMA
    "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
    "Connectivity", "Sim", "SPICE", "PCB", "SPICE Flat",
-#endif
-
    NULL			/* sentinel */
 };
 
@@ -558,7 +554,7 @@ void default_keybindings()
    add_binding(ALT | XK_u, XCF_Underline);
    add_binding(ALT | XK_o, XCF_Overline);
    add_binding(ALT | XK_e, XCF_ISO_Encoding);
-   add_binding(ALT | XK_Return, XCF_Return_Char);
+   add_binding(ALT | XK_Return, XCF_Linebreak);
    add_binding(ALT | XK_h, XCF_Halfspace);
    add_binding(ALT | XK_q, XCF_Quarterspace);
    add_binding(XK_backslash, XCF_Special);
@@ -641,8 +637,6 @@ void default_keybindings()
    add_binding(BUTTON2, XCF_Finish);
    add_binding(BUTTON3, XCF_Cancel);
    add_binding(ALT | XK_s, XCF_SnapTo);
-
-#ifdef SCHEMA
    add_binding(ALT | XK_q, XCF_Netlist);
    add_binding(XK_slash, XCF_Swap);
    add_binding(XK_T, XCF_Pin_Label);
@@ -657,7 +651,6 @@ void default_keybindings()
 /* add_binding(ALT | XK_a, XCF_SPICE);		*/
 /* add_binding(ALT | XK_f, XCF_SPICEflat);	*/
 /* add_binding(ALT | XK_p, XCF_PCB);		*/
-#endif
 
 }
 
