@@ -290,7 +290,6 @@ void pagecatbutton(XButtonEvent *event)
    if (event->button == Button1 || event->button == Button2) {
       if ((bpage = pageposition(mode, event, 0)) >= 0) {
 		  
-#ifdef SCHEMA
 	 if (eventmode == ASSOC_MODE) {
 	    if (mode == PAGELIB) {
 	       /* using changepage() allows use of new page for schematic */
@@ -306,9 +305,7 @@ void pagecatbutton(XButtonEvent *event)
 	    }
 	    return;
          }
-	 else
-#endif
-	 if (event->button == Button1) {
+	 else if (event->button == Button1) {
 
 	    /* like catreturn(), but don't actually go to the popped page */
 	    objectdeselect();
@@ -1173,7 +1170,6 @@ void copycat()
       (*newobj)->pcorner.x = oldobj->pcorner.x;
       (*newobj)->pcorner.y = oldobj->pcorner.y;
       (*newobj)->viewscale = oldobj->viewscale;
-#ifdef SCHEMA
       /* don't attach the same schematic. . . */
       (*newobj)->symschem = NULL;
 
@@ -1207,7 +1203,6 @@ void copycat()
       (*newobj)->valid = False;
       (*newobj)->traversed = False;
       (*newobj)->devname = NULL;
-#endif
       (*newobj)->hidden = False;
 
       /* copy over all the elements of the original object */
@@ -1290,9 +1285,7 @@ void copycat()
 	       (*nlabel)->justify = clabel->justify;
 	       (*nlabel)->string = stringcopy(clabel->string);
 	       (*nlabel)->passed = NULL;
-#ifdef SCHEMA
 	       (*nlabel)->pin = clabel->pin;
-#endif
                } break;
       
 	    case(OBJECT): {
@@ -1315,11 +1308,10 @@ void copycat()
 	       (*ninst)->bbox.width = cinst->thisobject->bbox.width;
 	       (*ninst)->bbox.height = cinst->thisobject->bbox.height;
 
-#ifdef SCHEMA
 	       (*ninst)->schembbox = NULL;
 
 	       /* here---deal with attached schematics */
-#endif
+
                } break;
          }
 	 (*newobj)->parts++;
@@ -1380,7 +1372,6 @@ void catbutton(u_int mode, XButtonEvent *event)
 
 	       /* setup to move object around and draw the selected object */
 
-#ifdef SCHEMA
 	       if (eventmode == ASSOC_MODE) {
 
 	          /* revert to old page */
@@ -1393,9 +1384,7 @@ void catbutton(u_int mode, XButtonEvent *event)
 		  catreturn();
 		  eventmode = PRESS_MODE;
 	       }
-	       else
-#endif
-               if (event->button == Button1) {
+	       else if (event->button == Button1) {
 
 	          /* revert to old page */
 
@@ -1464,6 +1453,8 @@ void catbutton(u_int mode, XButtonEvent *event)
                      eventmode = PRESS_MODE;
 	          }
 #ifdef TCL_WRAPPER
+		  /* fprintf(stderr, "Creating event handler for xctk_drag: "); */
+		  /* printeventmode();		*/
                   Tk_CreateEventHandler(areastruct.area, PointerMotionMask,
 			(Tk_EventProc *)xctk_drag, NULL);
 #endif
@@ -1543,11 +1534,9 @@ void startcatalog(xcWidget w, pointertype libmod, caddr_t nulldata)
       else
          eventmode = FONTCAT2_MODE;
    }
-#ifdef SCHEMA
    else if (eventmode == ASSOC_MODE) {
       XDefineCursor (dpy, areastruct.areawin, CROSS);
    }
-#endif
    else if (libmod == PAGELIB || libmod == LIBLIB) {
       XDefineCursor (dpy, areastruct.areawin, CROSS);
       eventmode = CATALOG_MODE;
