@@ -342,14 +342,14 @@ void setparammarks(genericptr thiselem)
 
    /* Reset all variables to false */
    for (i = 0; i < 14; i++)
-      Tcl_SetVar(xcinterp, (char *)paramvars[i], "false", TCL_NAMESPACE_ONLY);
+      Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[i], "false", TCL_NAMESPACE_ONLY);
 
    /* For each parameter declared, set the corresponding Tcl variable */
    if (thiselem != NULL) {
       for (epp = thiselem->passed; epp != NULL; epp = epp->next) {
 	 ops = match_param(topobject, epp->key);
 	 if (ops == NULL) continue;	/* error condition */
-         Tcl_SetVar(xcinterp, (char *)paramvars[ops->which], "true",
+         Tcl_SetVar2(xcinterp, "XCOps", (char *)paramvars[ops->which], "true",
 		TCL_NAMESPACE_ONLY);
       }
    }
