@@ -22,6 +22,7 @@ extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
 extern void objectdefaults(objinstptr, objectptr, int, int);
 extern void labeldefaults(labelptr, u_char, int, int);
+extern void poly_add_point(polyptr, XPoint *);
 extern void polydefaults(polyptr, int, int, int);
 extern void splinedefaults(splineptr, int, int);
 extern void arcdefaults(arcptr, int, int);
@@ -254,6 +255,7 @@ extern void findsplinepos(splineptr, float, XPoint *, int *);
 extern void ffindsplinepos(splineptr, float, XfPoint *);
 extern float findsplinemin(splineptr, XPoint *);
 extern short closepoint(polyptr, XPoint *);
+extern void updateinstparam(objectptr);
 extern short checkbounds();
 extern void window_to_user(short, short, XPoint *);
 extern void user_to_window(XPoint, XPoint *);
@@ -301,12 +303,10 @@ extern void UDrawSimpleLine(XPoint *, XPoint *);
 extern void UDrawLine(XPoint *, XPoint *);
 extern void UDrawCircle(XPoint *, u_char);
 extern void UDrawX(labelptr);
-#ifdef SCHEMA
 extern void UDrawXDown(labelptr);
 extern int  toplevelwidth(objinstptr, short *);
 extern int  toplevelheight(objinstptr, short *);
 extern void extendschembbox(objinstptr, XPoint *, XPoint *);
-#endif
 extern void pinadjust(short, short *, short *, short);
 extern void UDrawTextLine(labelptr, short);
 extern void UDrawTLine(labelptr);
@@ -478,7 +478,9 @@ extern Boolean dospecial(void);
 
 /* from netlist.c: */
 
-#ifdef SCHEMA
+extern Boolean RemoveFromNetlist(objectptr, genericptr);
+extern labelptr NetToLabel(int, objectptr);
+extern void NameToPosition(objinstptr, labelptr, XPoint *);
 extern void invalidate_netlist(objectptr);
 extern int updatenets(objinstptr);
 extern void createnets(objinstptr);
@@ -504,7 +506,6 @@ extern void mergecleanup(objectptr);
 extern void mergenets(objectptr, int, int);
 extern void removecall(objectptr, CalllistPtr);
 extern void addpin(objectptr, labelptr, int);
-extern void addglobal(labelptr, int);
 extern void addcall(objectptr, objectptr, objinstptr);
 extern Boolean addport(objectptr, int);
 extern void addportcall(objectptr, objinstptr, objectptr, int, int);
@@ -523,13 +524,15 @@ extern void writenet(objectptr, char *, char *);
 extern void writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
 extern void outputpcb(struct Ptab *, FILE *);
 extern void freepcb(struct Ptab *);
+extern void freepolylist(NetlistPtr);
+extern void freelabellist(NetlistPtr);
+extern void freeports(CalllistPtr);
 extern void freenets(objectptr);
 extern void freetemplabels(objectptr);
 extern void freeglobals();
 extern int cleartraversed(objectptr);
 extern int checkvalid(objectptr);
 extern void clearpins(objectptr);
-#endif
 
 /* from parameter.c: */ 
 
