@@ -98,10 +98,8 @@ xcWidget	 message1, message2, message3, top, toolbar, overlay = NULL;
 xcWidget   menuwidgets[MaxMenuWidgets];
 #endif
 
-#ifdef SCHEMA
 xcWidget   wschema, wsymb, netbutton;
 XtAppContext app;
-#endif
 
 Display  *dpy;	             /* Works well to make this globally accessible */
 Colormap cmap;
@@ -174,7 +172,6 @@ XContext XUniqueContext()
 
 static XtResource resources[] = {
 
-#ifdef SCHEMA
   /* schematic layout colors */
 
   { "globalpincolor", "GlobalPinColor", XtRPixel, sizeof(Pixel),
@@ -183,7 +180,8 @@ static XtResource resources[] = {
       XtOffset(ApplicationDataPtr, localcolor), XtRString, "Red"},
   { "infolabelcolor", "InfoLabelColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, infocolor), XtRString, "SeaGreen"},
-#endif
+  { "ratsnestcolor", "RatsNestColor", XtRPixel, sizeof(Pixel),
+      XtOffset(ApplicationDataPtr, ratsnestcolor), XtRString, "tan4"},
 
   /* non-schematic layout colors */
 
@@ -409,9 +407,7 @@ void makesubmenu(char *menuname, char *attachname, menuptr buttonmenu,
             addtocolorlist(menuwidgets[menusize], cval);
 	 }
 
-#ifdef SCHEMA
          if (strcmp(p->name, "Enable XSchema") || !areastruct.schemon)
-#endif
          XtManageChild (menuwidgets[menusize]);
       }
    }
@@ -605,15 +601,13 @@ void createmenus (xcWidget form, xcWidget *firstbutton, xcWidget *lastbutton)
       buttonw[i] = XtCreateWidget(TopButtons[i].name, 
 	 	XwmenuButtonWidgetClass, form, wargs, n); n = 0;
 
-#ifdef SCHEMA
       if (!strcmp(TopButtons[i].name, "Netlist")) {
 	 netbutton = buttonw[i];
 	 if (areastruct.schemon)
             XtManageChild(buttonw[i]);
       }
       else
-#endif
-      XtManageChild(buttonw[i]);
+         XtManageChild(buttonw[i]);
 
       if(TopButtons[i].submenu == NULL) 
 	 XtAddCallback(buttonw[i], XtNselect,
@@ -1244,13 +1238,8 @@ void writescalevalues(char *scdest, char *xdest, char *ydest)
    oscale = curpage->outscale;
    psscale = getpsscale(oscale, areastruct.page);
 
-#ifdef SCHEMA
-   width = toplevelwidth(curpage->pageinst);
-   height = toplevelheight(curpage->pageinst);
-#else
-   width = topobject->bbox.width;
-   height = topobject->bbox.height;
-#endif
+   width = toplevelwidth(curpage->pageinst, NULL);
+   height = toplevelheight(curpage->pageinst, NULL);
 
    sprintf(scdest, "%6.5f", oscale);
    if (curpage->coordstyle == CM) {
@@ -1825,14 +1814,12 @@ void printeventmode() {
       case UIPARAM_MODE:
 	 Fprintf(stderr, "UIPARAM");
 	 break;
-#ifdef SCHEMA
       case CONNECT_MODE:
 	 Fprintf(stderr, "CONNECT");
 	 break;
       case ASSOC_MODE:
 	 Fprintf(stderr, "ASSOC");
 	 break;
-#endif
    }
    Fprintf(stderr, "_MODE\'\n");
 }
@@ -2314,11 +2301,8 @@ void pre_initialize()
    areastruct.editstack = (objectptr) malloc(sizeof(object));
    areastruct.stack = NULL;   /* at the top of the hierarchy */
    initmem(areastruct.editstack);
-
-#ifdef SCHEMA
    areastruct.pinpointon = False;
    areastruct.schemon = False;
-#endif
 
    /* xobjs.numlibs = LIBS - LIBRARY; */
    xobjs.numlibs = LIBS - LIBRARY - 1;
@@ -2558,7 +2542,6 @@ void GUI_init(int argc, char *argv[])
    /* Supplementary message widgets go at the bottom */
    /*------------------------------------------------*/
 
-#ifdef SCHEMA
    XtnSetArg(XtNxResizable, False);
    XtnSetArg(XtNyRefWidget, abform);
    XtnSetArg(XtNyAddHeight, True);
@@ -2590,7 +2573,6 @@ void GUI_init(int argc, char *argv[])
 
    XtnSetArg(XtNxRefWidget, wschema);
    XtnSetArg(XtNxAddWidth, True);
-#endif
 
    XtnSetArg(XtNyRefWidget, abform);
    XtnSetArg(XtNyAddHeight, True);
@@ -2662,11 +2644,8 @@ void GUI_init(int argc, char *argv[])
    XtAddEventHandler(top, NoEventMask, True, (XtEventHandler)delwin, NULL);
 
    XtAddCallback(corner, XtNselect, (XtCallbackProc)zoomview, Number(1));
-
-#ifdef SCHEMA
    XtAddCallback (wsymb, XtNselect, (XtCallbackProc)swapschem, Number(0));
    XtAddCallback (wschema, XtNselect, (XtCallbackProc)swapschem, Number(0));
-#endif
 
    /*--------------------*/
    /* Realize the Widget */
@@ -2914,11 +2893,10 @@ void post_initialize()
    setcolorscheme(True);
    areastruct.color = DEFAULTCOLOR;
 
-#ifdef SCHEMA
    LOCALPINCOLOR = appdata.localcolor;
    GLOBALPINCOLOR = appdata.globalcolor;
    INFOLABELCOLOR = appdata.infocolor;
-#endif
+   RATSNESTCOLOR = appdata.ratsnestcolor;
    BBOXCOLOR = appdata.bboxpix;
 
    /* Now that we have values for the window width and height, we can initialize */
@@ -3018,14 +2996,12 @@ int main(int argc, char **argv)
    /* Check for schematic flag  */
    /*---------------------------*/
 
-#ifdef SCHEMA
    for (k = argc - 1; k > 0; k--) {
-      if (!strncmp(argv[k], SCHEM_FLAG, strlen(SCHEM_FLAG))) {
+      if (!strncmp(argv[k], "-schem", 6)) {
 	 areastruct.schemon = True;
 	 break;
       }
    }
-#endif
 
    GUI_init(argc, argv);
    post_initialize();
