@@ -156,10 +156,7 @@ typedef struct {
 #define MINAUTOSCALE 0.75 /* Won't automatically scale closer than this */
 #define MAXCHANGES 20 /* Number of changes to induce a temp file save	*/
 #define STIPPLES    8 /* Number of predefined stipple patterns		*/
-
-#ifdef SCHEMA
 #define PADSPACE   10 /* Spacing of pinlabels from their origins	*/
-#endif
 
 #ifdef HAVE_XPM
 #define TBBORDER   1  /* border around toolbar buttons */
@@ -203,13 +200,7 @@ CATPAN_MODE, CATALOG_MODE, CATTEXT_MODE, FONTCAT_MODE, FONTCAT2_MODE,
 TEXT1_MODE, TEXT2_MODE, TEXT3_MODE, WIRE_MODE, POLY_MODE, BOX0_MODE,
 BOX_MODE, EBOX_MODE, ARC0_MODE, ARC_MODE, EARC_MODE, SPLINE0_MODE,
 SPLINE_MODE, ESPLINE_MODE, EPATH_MODE, LPARAM_MODE, IPARAM_MODE,
-ULPARAM_MODE, UIPARAM_MODE
-
-#ifdef SCHEMA
-, CONNECT_MODE, ASSOC_MODE
-#endif
-
-};
+ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
 
 /*----------------------------------------------------------------------*/
 /* File loading modes							*/
@@ -341,8 +332,6 @@ ULPARAM_MODE, UIPARAM_MODE
 /* Schematic object types and pin label types	   			*/
 /*----------------------------------------------------------------------*/
 
-#ifdef SCHEMA
-
 #define PRIMARY 0		/* Primary (master) schematic page */
 #define SECONDARY 1		/* Secondary (slave) schematic page */
 #define TRIVIAL 2		/* Symbol as non-schematic element */
@@ -355,8 +344,6 @@ ULPARAM_MODE, UIPARAM_MODE
 
 #define HIERARCHY_LIMIT 256	/* Stop if recursion goes this deep */
 
-#endif
-
 /*----------------------------------------------------------------------*/
 /* Save types.	This list incorporates "ALL_PAGES", below.		*/
 /*----------------------------------------------------------------------*/
@@ -416,6 +403,8 @@ typedef XfPoint* fpointlist;
 #define PATH	32
 #define SEL_ANY	63  /* for selection mechanism only */
 
+#define REMOVE_TAG 64  /* add this value to objects to be removed */
+
 /*----------------------------------------------------------------------*/
 /* Allowed parameterization types					*/
 /*----------------------------------------------------------------------*/
@@ -477,7 +466,7 @@ typedef struct _oparam {
    u_char	which;		/* what the parameter represents (P_*) */
    union {
       stringpart *string;	/* xcircuit label type */
-      char	 *expr;		/* TCL (postscript) expression */
+      char	 *expr;		/* TCL (string) expression */
       int	  ivalue;	/* also covers type short int by typecasting */
       float	  fvalue;
    } parameter;			/* default or substitution value */
@@ -535,9 +524,7 @@ typedef struct {
    objectptr	thisobject;
    oparamptr	params;		/* parameter substitutions for this instance */
    BBox		bbox;		/* per-instance bounding box information */
-#ifdef SCHEMA
    BBox		*schembbox;	/* Extra bounding box for pin labels */
-#endif
 } objinst, *objinstptr;
 
 /* Linked-list for objects */
@@ -582,9 +569,7 @@ typedef struct {
    short	rotation;
    float	scale;
    short	justify;
-#ifdef SCHEMA
    u_char	pin;
-#endif
    stringpart	*string;
 } label, *labelptr;
 
@@ -655,8 +640,6 @@ typedef struct {
 /* Netlist structures for schematic capture				*/
 /*----------------------------------------------------------------------*/
 
-#ifdef SCHEMA
-
 /* Linked polygon list */
 
 typedef struct _Polylist *PolylistPtr;
@@ -742,8 +725,6 @@ typedef struct {
    objinstptr	thisinst;
 } Highlight;
 
-#endif
-
 /*----------------------------------------------------------------------*/
 /* Main object structure						*/
 /*----------------------------------------------------------------------*/
@@ -760,7 +741,6 @@ typedef struct _xcobject {
    genericptr	*plist;	 	/* to be retypecast to label, polygon, etc. */
    oparamptr	params;		/* list of parameters, with default values */
    
-#ifdef SCHEMA
    Highlight	highlight;	/* net to be highlighted on redraw */
    u_char	schemtype;
    objectptr	symschem;	/* schematic page support */
@@ -770,7 +750,6 @@ typedef struct _xcobject {
    NetlistPtr   netlist;
    PortlistPtr  portlist;
    CalllistPtr  calllist;
-#endif
 } object;
 
 /*----------------------------------------------------------------------*/
@@ -903,10 +882,8 @@ enum {DIRECTORY = 0, MATCH, NONMATCH};	/* file types */
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-#ifdef SCHEMA
    /* schematic layout colors */
-   Pixel	globalcolor, localcolor, infocolor;
-#endif
+   Pixel	globalcolor, localcolor, infocolor, ratsnestcolor;
 
    /* non-schematic layout color(s) */
    Pixel	bboxpix;
@@ -1012,11 +989,11 @@ enum {
    XCF_ENDDATA = -2, XCF_SPACER,
    XCF_Page, XCF_Justify, XCF_Superscript, XCF_Subscript, XCF_Normalscript,
    XCF_Nextfont, XCF_Boldfont, XCF_Italicfont, XCF_Normalfont, XCF_Underline,
-   XCF_Overline, XCF_ISO_Encoding, XCF_Return, XCF_Halfspace, XCF_Quarterspace,
+   XCF_Overline, XCF_ISO_Encoding, XCF_Halfspace, XCF_Quarterspace,
    XCF_Special, XCF_TabStop, XCF_TabForward, XCF_TabBackward,
    XCF_Text_Return, XCF_Text_Delete, XCF_Text_Right, XCF_Text_Left,
    XCF_Text_Up, XCF_Text_Down, XCF_Text_Split,
-   XCF_Text_Home, XCF_Text_End, XCF_Return_Char, XCF_Parameter,
+   XCF_Text_Home, XCF_Text_End, XCF_Linebreak, XCF_Parameter,
    XCF_Edit_Param,XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
    XCF_Edit_Append, XCF_Edit_Next, XCF_Attach,
    XCF_Next_Library, XCF_Library_Directory,
@@ -1031,11 +1008,8 @@ enum {
    XCF_Edit, XCF_Undelete, XCF_Select_Save, XCF_Unselect, XCF_Dashed,
    XCF_Dotted, XCF_Solid, XCF_Prompt, XCF_Dot, XCF_Wire, XCF_Start,
    XCF_Finish, XCF_Cancel, XCF_Nothing, XCF_Exit,
-
-#ifdef SCHEMA
    XCF_Netlist, XCF_Swap, XCF_Pin_Label, XCF_Pin_Global, XCF_Info_Label,
    XCF_Connectivity, XCF_Sim, XCF_SPICE, XCF_PCB, XCF_SPICEflat,
-#endif
    NUM_FUNCTIONS
 };
 
@@ -1100,10 +1074,8 @@ typedef struct {
    Boolean	mapped;		/* indicates if window is drawable */
    Boolean	filefilter;	/* Is the file list filtered? */
    Boolean	editinplace;
-#ifdef SCHEMA
    Boolean	schemon;
    Boolean	pinpointon;
-#endif
 #ifdef HAVE_XPM
    Boolean	toolbar_on;
 #endif
